[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]
[torsocks/master] Fix typo: subsytem → subsystem.
commit c822b5c2cdac0d9f7e0706de488d282bebd2e543
Author: intrigeri <intrigeri@xxxxxxxx>
Date: Wed Oct 19 20:55:26 2016 +0000
Fix typo: subsytem â?? subsystem.
---
src/lib/torsocks.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/src/lib/torsocks.c b/src/lib/torsocks.c
index 731b33c..f1be6bc 100644
--- a/src/lib/torsocks.c
+++ b/src/lib/torsocks.c
@@ -256,7 +256,7 @@ error_dlopen:
}
/*
* Initialize logging subsytem using either the default values or the one given
* by the environment variables.
*/
static void init_logging(void)
@@ -299,7 +299,7 @@ static void init_logging(void)
/* After this, it is safe to call any logging macros. */
- DBG("Logging subsytem initialized. Level %d, file %s, time %d",
+ DBG("Logging subsystem initialized. Level %d, file %s, time %d",
level, filepath, t_status);
}
_______________________________________________
@@ -256,7 +256,7 @@ error_dlopen:
}
/*
- * Initialize logging subsytem using either the default values or the one given
+ * Initialize logging subsystem using either the default values or the one given
* by the environment variables.
*/
tor-commits mailing list
tor-commits@xxxxxxxxxxxxxxxxxxxx
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits